@@ -9,6 +9,9 @@ from zeropass import conf
 class TokenForm(forms.Form):
 
     email = forms.EmailField()
+    next = forms.CharField(
+        required=False,
+        widget=forms.HiddenInput())
 
     def clean_email(self):
         email = self.cleaned_data['email']
@@ -21,5 +24,6 @@ class TokenForm(forms.Form):
     def save(self):
         token = Token()
         token.user = self.user
+        token.next = self.cleaned_data.get('next')
         token.expires = datetime.now() + timedelta(seconds=conf.EXPIRES)
         token.save()
