@@ -10,8 +10,10 @@ from zeropass.forms import TokenForm
 def login(request):
     """processes or displays a form depending on
     whether or not post data is present"""
-
-    form = TokenForm(request.POST or None)
+    initial = {'next': request.GET.get('next')}
+    form = TokenForm(
+        request.POST or None,
+        initial=initial)
 
     if form.is_valid():
         token = form.save()
